@@ -5,6 +5,7 @@ Convert output file from a given code/format into TREXIO
 
 import os
 from group_tools import basis as trexio_basis
+from group_tools import determinant as trexio_det
 
 try:
     import trexio
@@ -18,7 +19,7 @@ except ImportError as exc:
 
 
 
-def run_resultsFile(trexio_filename, filename, back_end, motype=None):
+def run_resultsFile(trexio_filename, filename, back_end):
 
     if os.path.exists(filename):
         os.system("rm -rf -- "+trexio_filename)
@@ -66,10 +67,8 @@ def run_resultsFile(trexio_filename, filename, back_end, motype=None):
     trexio.write_nucleus_num(trexio_file, nucleus_num)
     trexio.write_nucleus_coord(trexio_file, coord)
     # nucleus_charge will be written later after removing core electrons with ECP
-    # trexio.write_nucleus_charge(trexio_file, charge)
 
-
-    # Transformt H1 into H
+    # Transform H1 into H
     import re
     p = re.compile(r'(\d*)$')
     label = [p.sub("", x.name).capitalize() for x in res.geometry]
@@ -142,7 +141,11 @@ def run_resultsFile(trexio_filename, filename, back_end, motype=None):
 
         ao_shell.append(curr_shell)
 
-    nucl_shell_num.append(nucleus_index[-1]-nucleus_index[-2])
+    if len(nucleus_index) > 1:
+        nucl_shell_num.append(nucleus_index[-1]-nucleus_index[-2])
+    else:
+        # cade of a single atom
+        nucl_shell_num.append(curr_shell + 1)
 
     shell_num = curr_shell+1
     prim_num = len(exponent)
@@ -243,11 +246,8 @@ def run_resultsFile(trexio_filename, filename, back_end, motype=None):
     # MOs
     # ---
 
-    if motype is None:
-        MO_type = res.determinants_mo_type
-    else:
-        MO_type = motype
-    print ("available motypes", res.mo_types)
+    MO_type = res.determinants_mo_type
+    #print ("available motypes", res.mo_types)
 
     allMOs = res.mo_sets[MO_type]
     trexio.write_mo_type(trexio_file, MO_type)
@@ -381,9 +381,42 @@ def run_resultsFile(trexio_filename, filename, back_end, motype=None):
     # end if res.pseudo:
     trexio.write_nucleus_charge(trexio_file, charge)
 
-    # Electrons
+    # Determinants
     # ---------
 
+    # resultsFile has non-empty det_coefficients sometimes
+    if len(res.det_coefficients[0]) > 1:
+
+        int64_num       = int((mo_num-1)/64) + 1
+        determinant_num = len(res.det_coefficients[0])
+
+        # sanity check
+        if res.num_states > 1:
+            assert determinant_num == len(res.det_coefficients[1])
+
+        # construct the determinant_list of integer bitfields from resultsFile determinants reprsentation
+        det_list = []
+        for i in range(determinant_num):
+            det_tmp      = []
+            orb_list_up  = [ orb+1 for orb in res.determinants[i].get("alpha") ]
+            det_tmp     += trexio_det.to_determinant_list(orb_list_up, int64_num)
+            orb_list_dn  = [ orb+1 for orb in res.determinants[i].get("beta") ]
+            det_tmp     += trexio_det.to_determinant_list(orb_list_dn, int64_num)
+
+            det_list.append(det_tmp)
+
+        # write the CI determinants
+        offset_file = 0
+        trexio.write_determinant_list(trexio_file, offset_file, determinant_num, det_list)
+
+        # write the CI coefficients
+        offset_file = 0
+        for s in range(res.num_states):
+            trexio_file.set_state(s)
+            trexio.write_determinant_coefficient(trexio_file, offset_file, determinant_num, res.det_coefficients[s])
+
+
+    # close the file before leaving
     trexio_file.close()
 
     print("Conversion to TREXIO format has been completed.")
@@ -391,15 +424,14 @@ def run_resultsFile(trexio_filename, filename, back_end, motype=None):
     return
 
 
-def run(trexio_filename, filename, filetype, back_end, motype=None):
+def run(trexio_filename, filename, filetype, back_end):
     if filetype.lower() == "gaussian":
         run_resultsFile(trexio_filename, filename, back_end)
     elif filetype.lower() == "gamess":
-        run_resultsFile(trexio_filename, filename, back_end, motype)
+        run_resultsFile(trexio_filename, filename, back_end)
     elif filetype.lower() == "fcidump":
         run_fcidump(trexio_filename, filename, back_end)
     elif filetype.lower() == "molden":
-        run_fcidump(trexio_filename, filename, back_end)
+        run_molden(trexio_filename, filename, back_end)
     else:
         raise TypeError("Unknown file type")
-
