@@ -2,9 +2,9 @@
 
 import trexio
 import numpy as np
-import nucleus as trexio_nucleus
-import basis as trexio_basis
-import ao as trexio_ao
+from . import nucleus as trexio_nucleus
+from . import basis as trexio_basis
+from . import ao as trexio_ao
 
 def run(trexio_file, n_points):
     """
@@ -12,6 +12,11 @@ def run(trexio_file, n_points):
     the matrix stored in the file.
     """
 
+    if not trexio.has_ao_1e_int_overlap(trexio_file):
+      raise Exception(
+        "One-electron overlap integrals are missing in the TREXIO file. Required for check-basis."
+        )
+
     ao = trexio_ao.read(trexio_file)
     basis = ao["basis"]
     nucleus = basis["nucleus"]
@@ -25,12 +30,13 @@ def run(trexio_file, n_points):
     step = [ None for i in range(3) ]
     for a in range(3):
       linspace[a], step[a] = np.linspace(rmin[a]-shift[a], rmax[a]+shift[a], num=n_points, retstep=True)
-    print (step)
+      
+    print("Integration steps:", step)
     dv = step[0]*step[1]*step[2]
 
     S = np.zeros( [ ao["num"], ao["num"]] )
     for x in linspace[0]:
-      print(".",end='',flush=True)
+      #print(".",end='',flush=True)
       for y in linspace[1]:
         for z in linspace[2]:
            chi = trexio_ao.value(ao, np.array( [x,y,z] ) )
@@ -40,9 +46,10 @@ def run(trexio_file, n_points):
     ao_num = ao["num"]
     S_ex = trexio.read_ao_1e_int_overlap(trexio_file)
     S_diff = S - S_ex
-    print ("Norm of the error: %f"%(np.linalg.norm(S_diff)))
-    print(S_diff)
+    print("Norm of the error: %f"%(np.linalg.norm(S_diff)))
+    #print(S_diff)
 
+    # This produces a lot of output for large molecules, maybe wrap up in ``if debug`` statement ?
     for i in range(ao_num):
       for j in range(i,ao_num):
         print("%3d %3d %15f %15f"%(i,j,S[i][j],S_ex[i,j]))
